@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.044'; # VERSION
+our $VERSION = '0.045'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -62,11 +62,11 @@ App::Pinto::Command::edit - change stack properties
 
 =head1 VERSION
 
-version 0.044
+version 0.045
 
 =head1 SYNOPSIS
 
-  pinto --root=REPOSITORY_ROOT stack edit [OPTIONS] [STACK]
+  pinto --root=REPOSITORY_ROOT edit [OPTIONS] [STACK]
 
 =head1 DESCRIPTION
 
@@ -88,9 +88,9 @@ currently marked as default.  Stack names must be alphanumeric
 =item --default
 
 Causes the selected stack to be marked as the "default".  The
-"default" stack becomes the default for all operations where you do no
+default stack becomes the default for all operations where you do no
 not specify an explicit stack.  The default stack also governs the
-index file for your repository.  DO NOT CHANGE THE DEFAULT STACK
+static index file for your repository.  DO NOT CHANGE THE DEFAULT STACK
 WITHOUT DUE DILLIGENCE.  It has broad impact, especially if your
 repository has multiple users.
 
