@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.044'; # VERSION
+our $VERSION = '0.045'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -64,11 +64,11 @@ App::Pinto::Command::props - show stack properties
 
 =head1 VERSION
 
-version 0.044
+version 0.045
 
 =head1 SYNOPSIS
 
-  pinto --root=REPOSITORY_ROOT stack props [OPTIONS] STACK
+  pinto --root=REPOSITORY_ROOT props [OPTIONS] STACK
 
 =head1 DESCRIPTION
 
